angular.module('controllers', [])


.controller('HomeCtrl', HomeController)
.controller('AppCtrl', AppCtrl)
.controller('ConfiguracionCtrl', ConfiguracionCtrl)
.controller('ContactoCtrl', ContactoCtrl)


HomeController.$inject = ['$scope', '$ionicModal', 'CommonCode', 'PoisService', '$timeout', 'Config', '$ionicLoading', '$location'];
AppCtrl.$inject = ['$scope', '$cordovaPush', '$http', 'PoisService', 'ionPlatform', 'Config'];

function AppCtrl ($scope, $cordovaPush, $http, PoisService, ionPlatform, Config) {

    if (ionic.Platform.isWebView()) {

        window.analytics.startTrackerWithId('UA-58947771-1');
        window.analytics.trackView('Home ('+device.platform+')');

        ionPlatform.ready.then(function (device) {

            var registrado = window.localStorage['registrado'] || '';
            if (!registrado || registrado === '') {
                $scope.register();
            }
        });
    }

    /**
    * Registro del token
    **/
    $scope.register = function () {
        var config = null;

        if (ionic.Platform.isAndroid()) {
            config = {
                "senderID": "772443374512" // REPLACE THIS WITH YOURS FROM GCM CONSOLE - also in the project URL like: https://console.developers.google.com/project/434205989073
            };
        }
        else if (ionic.Platform.isIOS()) {
            config = {
                "badge": "true",
                "sound": "true",
                "alert": "true"
            }
        }

        $cordovaPush.register(config).then(function (result) {


            $scope.registerDisabled=true;
            // ** NOTE: Android regid result comes back in the pushNotificationReceived, only iOS returned here
            if (ionic.Platform.isIOS()) {
                $scope.regId = result;
                storeDeviceToken("ios");
            }
        }, function (err) {
            alert("Register error " + err)
        });
    }

    // Notification Received
    $scope.$on('$cordovaPush:notificationReceived', function (event, notification) {
        console.log(JSON.stringify([notification]));
        if (ionic.Platform.isAndroid()) {
            handleAndroid(notification);
        }
        else if (ionic.Platform.isIOS()) {
            handleIOS(notification);
            $scope.$apply(function () {
                $scope.notifications.push(JSON.stringify(notification.alert));
            })
        }
    });

    // Android Notification Received Handler
    function handleAndroid(notification) {
        // ** NOTE: ** You could add code for when app is in foreground or not, or coming from coldstart here too
        //             via the console fields as shown.
        console.log("In foreground " + notification.foreground  + " Coldstart " + notification.coldstart);
        if (notification.event == "registered") {
            $scope.regId = notification.regid;
            storeDeviceToken("android");
        }
        else if (notification.event == "message") {
            $cordovaDialogs.alert(notification.message, "Push Notification Received");
            $scope.$apply(function () {
                $scope.notifications.push(JSON.stringify(notification.message));
            })
        }
        else if (notification.event == "error")
            $cordovaDialogs.alert(notification.msg, "Push notification error event");
        else $cordovaDialogs.alert(notification.event, "Push notification handler - Unprocessed Event");
    }

    // IOS Notification Received Handler
    function handleIOS(notification) {

        if (notification.foreground == "1") {

            if (notification.sound) {
                var mediaSrc = $cordovaMedia.newMedia(notification.sound);
                mediaSrc.promise.then($cordovaMedia.play(mediaSrc.media));
            }

            if (notification.body && notification.messageFrom) {
                $cordovaDialogs.alert(notification.body, notification.messageFrom);
            }
            else $cordovaDialogs.alert(notification.alert, "Push Notification Received");

            if (notification.badge) {
                $cordovaPush.setBadgeNumber(notification.badge).then(function (result) {
                    console.log("Set badge success " + result)
                }, function (err) {
                    console.log("Set badge error " + err)
                });
            }
        }

        else {
            if (notification.body && notification.messageFrom) {
                $cordovaDialogs.alert(notification.body, "(RECEIVED WHEN APP IN BACKGROUND) " + notification.messageFrom);
            }
            else $cordovaDialogs.alert(notification.alert, "(RECEIVED WHEN APP IN BACKGROUND) Push Notification Received");
        }

    }

    // Stores the device token in a db using node-pushserver (running locally in this case)
    //
    // type:  Platform type (ios, android etc)
    function storeDeviceToken(type) {

        console.log("Call storeDeviceToken ["+type+"]");

        var datos = { uid: device.uuid, 
                     so: type, 
                     token: $scope.regId,
                     user: 'user' + Math.floor((Math.random() * 10000000) + 1) };
        


        PoisService.registerToken(datos)
        .then(function(data) 
        {
            window.localStorage['registrado'] = datos.token;
            console.log("Token registrado: "+datos.token);

        }, function(error,status) {
            // promise rejected, could log the error with: console.log('error', error);
            console.log("Error "+error+" status: "+status);
        });



        // PoisService.registerToken ()
        // console.log(" \n\r "+Config.BASE_URL+"/pois/add_token?uid="+device.uuid+"&so="+type+"&token="+$scope.regId+"&user="+usuario+" \n\r ");
        // $http.post(Config.BASE_URL+"/pois/add_token?uid="+device.uuid+"&so="+type+"&token="+$scope.regId+"&user="+usuario)
        // //$http.post(Config.BASE_URL+"/pois/add_token", datos)
        //     .success(function (data, status) {
        //         alert("Token stored, device is successfully subscribed to receive push notifications.");
        //         alert(data);
        //     })
        //     .error(function (data, status) {
        //         alert("Error storing device token." + data + " " + status)
        //     }
        // );

    }

    // Removes the device token from the db via node-pushserver API unsubscribe (running locally in this case).
    // If you registered the same device with different userids, *ALL* will be removed. (It's recommended to register each
    // time the app opens which this currently does. However in many cases you will always receive the same device token as
    // previously so multiple userids will be created with the same token unless you add code to check).
    function removeDeviceToken() {
        var tkn = {"token": $scope.regId};
        $http.post('http://192.168.1.16:8000/unsubscribe', JSON.stringify(tkn))
            .success(function (data, status) {
                console.log("Token removed, device is successfully unsubscribed and will not receive push notifications.");
            })
            .error(function (data, status) {
                console.log("Error removing device token." + data + " " + status)
            }
        );
    }

    // Unregister - Unregister your device token from APNS or GCM
    // Not recommended:  See http://developer.android.com/google/gcm/adv.html#unreg-why
    //                   and https://developer.apple.com/library/ios/documentation/UIKit/Reference/UIApplication_Class/index.html#//apple_ref/occ/instm/UIApplication/unregisterForRemoteNotifications
    //
    // ** Instead, just remove the device token from your db and stop sending notifications **
    $scope.unregister = function () {
        console.log("Unregister called");
        removeDeviceToken();
        $scope.registerDisabled=false;
        //need to define options here, not sure what that needs to be but this is not recommended anyway
//        $cordovaPush.unregister(options).then(function(result) {
//            console.log("Unregister success " + result);//
//        }, function(err) {
//            console.log("Unregister error " + err)
//        });
    }


}

function HomeController ($scope, $ionicModal, CommonCode, PoisService,$timeout, Config, $ionicLoading, $location) {

    var vm = this;
    vm.init = init;
    vm.goTo = goTo;
    vm.refresh = refresh;

    $ionicLoading.show ({
        templateUrl: "templates/loading/info.html"
    });

    init();

    function init () {
        $timeout(ObtenerPois, 1000);
    }

    function goTo (url) {
        $location.path(url);
    }

    function ObtenerPois () {

        PoisService.get(Config.BASE_URL+"/pois?count=3&mode=compact")
        .then(function(data) 
        {
            // Título para la vista, obtenido desde la respuesta
            vm.message = data.message;
            
            // Le paso al View el array de pois
            vm.pois = data.data.pois;
            
            // Le paso al View el n_pois
            vm.n_pois = data.data.n_pois;
            
            // Le paso al View el n_comments
            vm.n_comments = data.data.comments;

            // Oculto loading
            $ionicLoading.hide();
        
        }, function(error) {
            // promise rejected, could log the error with: console.log('error', error);
            alert("Error");
        });

    }
    // Refrescar la tabla de avisos
    function refresh () {
        ObtenerPois();
        console.log("Refresco los datos");
        $scope.$broadcast('scroll.refreshComplete');
    };


}


function ConfiguracionCtrl ($scope, Config, CommonCode, PoisService) {

    var vm = this;
    var common = CommonCode;
    vm.typeChange = typeChange;

    common.setVisit ("Configuración RadarCas");

    function typeChange (type,status) {

        window.localStorage["type_"+type] = status;

        PoisService.setType (device.uuid, type, status).then( function (data) 
        {
            console.log("UID:"+device.uuid + " Data: "+data);
        }, function(error) {
            console.log("UID:"+device.uuid + " Error: "+error);
        });        

    };

    var type_2 = window.localStorage["type_2"] || true; if (type_2==="false") type_2 = false; if (type_2==="true") type_2 = true;
    var type_3 = window.localStorage["type_3"] || true; if (type_3==="false") type_3 = false; if (type_3==="true") type_3 = true;
    var type_4 = window.localStorage["type_4"] || true; if (type_4==="false") type_4 = false; if (type_4==="true") type_4 = true;
    var type_6 = window.localStorage["type_6"] || true; if (type_6==="false") type_6 = false; if (type_6==="true") type_6 = true;
    var type_8 = window.localStorage["type_8"] || true; if (type_8==="false") type_8 = false; if (type_8==="true") type_8 = true;
    
    var typePois = [];
    typePois.push ({ id: 2, text: "Radares", checked: type_2 });
    typePois.push ({ id: 3, text: "Accidentes", checked: type_3 });
    typePois.push ({ id: 4, text: "Retenciones", checked: type_4 });
    typePois.push ({ id: 6, text: "Helicóptero", checked: type_6 });
    typePois.push ({ id: 8, text: "Info. general", checked: type_8 });
    $scope.typePois = typePois;

}

function ContactoCtrl ($scope, Config, CommonCode, $ionicLoading, PoisService) { 
    
    var vm = this;
    var common = CommonCode;
    vm.sendContact = sendContact;

    function sendContact (task) {
        
        vm.showFormSendPoi = false;
        vm.desactivar = true;

        $ionicLoading.show ({
            template: "Enviando mensaje. <br>Un momento por favor."
        });

        console.log("Enviando mensaje de contacto.");
        console.log(task);


        PoisService.contact(Config.BASE_URL+"/pois/contact",task)
        .then(function(data) 
        {
            console.log(data);
            common.message(data.message,data.description,data);
            common.setVisit ("Mensaje de contacto");
            $ionicLoading.hide();
        
        }, function(error) {
            // promise rejected, could log the error with: console.log('error', error);
            alert("Error");
        });


    };
}
