/**
*
* Controlador para los Pois / Avisos
*
**/

angular
    .module('starter')	
	.controller('PoisController', PoisController)


function PoisController ($scope, Config, $http, $ionicLoading, $stateParams, CommonCode, PoisService,$timeout, $cordovaSocialSharing) {

    var vm = this;
    var common = CommonCode;

    // Mensaje de "Cargando información..."
    $ionicLoading.show ({
        templateUrl: "templates/loading/info.html"
    });

    // Petición de los últimos Pois
    $timeout(ObtenerPois, 1500);

    vm.confirmPoi = confirmPoi;
    vm.sendPoi = sendPoi;
    vm.goTo = goTo;
    vm.shareViaWhatsApp = shareViaWhatsApp;
    vm.refresh = refresh;
    vm.sendComment = sendComment;

    function goTo (url) {
        $location.path(url);
    }

    function ObtenerPois () {

        PoisService.get(Config.BASE_URL+"/pois?mode=compact")
        .then(function(data) 
        {

            common.setVisit ("Obteniendo avisos");

            // Título para la vista, obtenido desde la respuesta
            vm.message = data.message;
            
            // Le paso al View el array de pois
            vm.pois = data.data.pois;
            
            // Oculto loading
            $ionicLoading.hide();
        
        }, function(error) {
            // promise rejected, could log the error with: console.log('error', error);
            alert("Error");
        });

    }

    function shareViaWhatsApp (msg) {

        var message_radarcas =  msg + " Enviado por RadarCas https://goo.gl/2oHOmg (iOS) / https://goo.gl/l6uDYV (Android)"
        $cordovaSocialSharing.shareViaWhatsApp(message_radarcas, null , null, function() {
            console.log('share ok')
        }, function(errormsg){
            alert(errormsg)
        });

    }

    // Información del POI
    if ($stateParams.pid) {

        console.log("GET info del aviso: "+ $stateParams.pid);
        vm.loading_poi = true;
        vm.loading_comments = true;

        PoisService.get(Config.BASE_URL+"/pois?pid=" + $stateParams.pid)
        .then(function(data) 
        {
            vm.message = data.message;

            vm.poi = data.data.pois[0];
            $ionicLoading.hide();
            
            common.setVisit (vm.poi.address);
            vm.loading_poi = false;

            PoisService.get(Config.BASE_URL+"/pois/comments?pid=" + $stateParams.pid)
            .then(function(data) 
            {
	            vm.loading_comments = false;
	            vm.comments = data.data;
            }, function(error) {
                alert("Error");
            });


        }, function(error) {
            alert("Error");
        });


    }

    // Refrescar la tabla de avisos
    function refresh () {
        vm.getPois();
        console.log("Refresco los datos");
        common.setVisit ("Refrescando avisos");

        $scope.$broadcast('scroll.refreshComplete');

    }

    function sendComment (t,poi) {

        vm.desactivar = true;

        console.log("Comentando el POI #"+poi);

        $ionicLoading.show ({
            templateUrl: "templates/loading/sendComment.html"
        });

        $http.jsonp("http://api.radarescastellon.com/pois/comment?callback=JSON_CALLBACK", 
        { params : 
                    { comment : t.comment,
                      poi : poi,
                      uid : 123
                    }
        }).success(function (result) {
            console.log("Enviado! Resultado: "+result.code);
            common.setVisit ("Comentario enviado");

            $ionicLoading.hide();

            if (result.code === 200 || result.code == "200") {
                console.log("mensaje enviado");
                common.message(result.message,result.description,result);
            } else {
                console.log("mensaje NO enviado");
                common.message(result.message,result.description,result);
            }
        }).error(function(data, status, headers, config) {
            console.log("error");

            //message($scope,'Problemas técnicos','Se ha producido un error al enviar el comentario, por favor inténtalo de nuevo en unos segundos.',data);
        });
    }

    
    function sendPoi (task) {
        
        vm.showFormSendPoi = false;
        vm.desactivar = true;
        $ionicLoading.show ({
            templateUrl: "templates/loading/sendPoi.html"
        });

        console.log("--> Submitting form: "+task);
        console.log(task);


        PoisService.publish(Config.BASE_URL+"/pois/publish",task)
        .then(function(data) 
        {
            console.log(data);
            common.message(data.message,data.description,data);
            common.setVisit ("Aviso enviado");

            // // Título para la vista, obtenido desde la respuesta
            // vm.message = data.message;
            
            // // Le paso al View el array de pois
            // vm.pois = data.data;
            
            // // Oculto loading
            $ionicLoading.hide();
        
        }, function(error) {
            // promise rejected, could log the error with: console.log('error', error);
            alert("Error");
        });


    };


    /**
     * Confirmación de aviso
     * @param int poi Identificador (id) del aviso
     */
    function confirmPoi (poi) {

        console.log("Confirmo poi id: "+poi);
        $ionicLoading.show ({
            templateUrl: "templates/loading/sendPoi.html"
        });

        PoisService.get(Config.BASE_URL+"/pois/confirm?poi="+poi)
        .then(function(data) 
        {
            common.setVisit ("Poi confirmado");

            // // Oculto loading
            $ionicLoading.hide();

            common.message(data.message,data.description,data);            
        }, function(error) {
            // promise rejected, could log the error with: console.log('error', error);
            alert("Error");
        });

    }


}